summaryrefslogtreecommitdiffstats
path: root/smb4k/searchdlg/smb4ksearchdialogitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/searchdlg/smb4ksearchdialogitem.h')
-rw-r--r--smb4k/searchdlg/smb4ksearchdialogitem.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/smb4k/searchdlg/smb4ksearchdialogitem.h b/smb4k/searchdlg/smb4ksearchdialogitem.h
index 97dbbc9..9b070b9 100644
--- a/smb4k/searchdlg/smb4ksearchdialogitem.h
+++ b/smb4k/searchdlg/smb4ksearchdialogitem.h
@@ -32,7 +32,7 @@
#include <config.h>
#endif
-// Qt includes
+// TQt includes
#include <klistview.h>
// application specific includes
@@ -56,7 +56,7 @@ class Smb4KSearchDialogItem : public KListViewItem
* text according to the contents of @p item. If the search failed
* and @p item is empty, an error message will be displayed.
*
- * @param listBox The parent list box.
+ * @param listBox The tqparent list box.
*
* @param item The host item that represents the search
* result.
@@ -76,7 +76,7 @@ class Smb4KSearchDialogItem : public KListViewItem
* here.
*
* Make sure you copy the contents to a new item, because the pointer
- * will be invalidated if this Smb4KSearchDialogItem is deleted.
+ * will be tqinvalidated if this Smb4KSearchDialogItem is deleted.
*
* @returns the encapsulated Smb4KHostItem object.
*/
@@ -115,7 +115,7 @@ class Smb4KSearchDialogItem : public KListViewItem
int serialNumber() const { return m_serial; }
/**
* Reimplemented from QListViewItem. It is used for sorting and compares the
* serial numbers of this item and @p item. If @p ascending is TRUE and the
* serial number of this item is greater than that of @p item, it will be inserted
* before @p item and else it will be inserted after. In this implementation,
@@ -132,7 +132,7 @@ class Smb4KSearchDialogItem : public KListViewItem
* they are not. Which value and especially which algebraic sign is returned depends
* on the values that are returned by of both serialNumber() functions and on @p ascending.
*/
- int compare( QListViewItem *item, int col, bool ascending ) const;
+ int compare( TQListViewItem *item, int col, bool ascending ) const;
private:
/**
@@ -115,7 +115,7 @@ class Smb4KSearchDialogItem : public KListViewItem
int serialNumber() const { return m_serial; }
/**
- * Reimplemented from QListViewItem. It is used for sorting and compares the
+ * Reimplemented from TQListViewItem. It is used for sorting and compares the
* serial numbers of this item and @p item. If @p ascending is TRUE and the
* serial number of this item is greater than that of @p item, it will be inserted